aboutsummaryrefslogtreecommitdiffstats
path: root/web/cobrands/highwaysengland/assets.js
diff options
context:
space:
mode:
Diffstat (limited to 'web/cobrands/highwaysengland/assets.js')
-rw-r--r--web/cobrands/highwaysengland/assets.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/web/cobrands/highwaysengland/assets.js b/web/cobrands/highwaysengland/assets.js
index 8e50ed396..5943cdffd 100644
--- a/web/cobrands/highwaysengland/assets.js
+++ b/web/cobrands/highwaysengland/assets.js
@@ -61,9 +61,9 @@ fixmystreet.assets.add(defaults, {
no_asset_msg_id: '#js-not-he-road',
actions: {
found: function(layer, feature) {
// If the road isn't in area 7 then we want to show the not found message.
fixmystreet.message_controller.road_found(layer, feature, function(feature) {
- if (feature.attributes.area_name === 'Area 7') {
+ if (feature.attributes.area_name.indexOf('DBFO') === -1) {
$('#js-top-message').show();
$('#form_category_row').show();
return true;
@@ -72,7 +72,7 @@ fixmystreet.assets.add(defaults, {
$('#form_category_row').hide();
return false;
}
- }, '#js-not-area7-road');
+ }, '#js-dbfo-road');
},
not_found: function(layer) {
fixmystreet.message_controller.road_not_found(layer);
@@ -61,9 +61,9 @@ fixmystreet.assets.add(defaults, {
actions: {
found: function(layer, feature) {
- // If the road isn't in area 7 then we want to show the not found message.
+ // If the road is a DBFO road then we want to show the not found message.
fixmystreet.message_controller.road_found(layer, feature, function(feature) {